<!---
I am a concrete subclass of abstractmigration that bases it's minor
versions on a SQL file.  Each statement must be terminated by a
semicolon and all strings must be single-quoted with doubling escapes
(i.e. backslash escapes are NOT supported).  The SQL file should be
placed in the scripts directory with an ".sql" extension, and an
instance of this CFC will be created to front it automatically.  Each
statement corresponds to a minor version, there is no support for
groups of statements making up a single minor version.  This includes
transaction demarcation statements.
------------------------------------------------------------------------
$Id: basemigration.cfc 2317 2007-06-02 05:47:55Z barneyb $

Copyright 2007 Barney Boisvert (bboisvert@gmail.com).

Licensed under the Apache License, Version 2.0 (the "License"); you may
not use this file except in compliance with the License. You may obtain
a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
--->
<cfcomponent output="false" extends="abstractmigration">

	<cffunction name="init" access="public" output="false" returntype="sqlbasedmigration">
		<cfargument name="dsn" type="string" required="true" />
		<cfargument name="sqlFile" type="string" required="true" />
		<cfset super.init(dsn) />
		<cffile action="read"
			file="#sqlFile#"
			charset="utf-8"
			variable="variables.my.sql" />
		<cfset digestSql() />
		<cfreturn this />
	</cffunction>
	

	
	<cffunction name="getMaxMinorVersion" access="public" output="false" returntype="numeric"
		hint="I am called get the maximum minor version provided by this migration.">
		<cfreturn arrayLen(variables.my.statements) />
	</cffunction>
	

	
	<cffunction name="doMinorVersion" access="public" output="false" returntype="void"
		hint="I am called to perform the given minor version upgrade.  It is safe to assume that the schema is currently at (minorVersion - 1) when this method is invoked.">
		<cfargument name="minorVersion" type="numeric" required="true" />
		<cfset var sql = variables.my.statements[minorVersion] />
		<cfquery datasource="#variables.my.dsn#" name="">
			#preserveSingleQuotes(sql)#
		</cfquery>
	</cffunction>
	
	
	
	<cffunction name="digestSql" access="private" output="false" returntype="void">
		<cfset var statements = listToArray(variables.my.sql, ";") />
		<cfset var i = "" />
		<cfscript>
			for (i = 1; i LTE arrayLen(statements); i = i + 1) {
				while (len(REReplace(statements[i], "[^']+", "", "all")) MOD 2 EQ 1) {
					statements[i] = statements[i] & ";" & statements[i + 1];
					arrayDeleteAt(statements, i + 1);
				}
			}
		</cfscript>
		<cfset variables.my.statements = statements />
	</cffunction>

<cfoutput></cfoutput>
</cfcomponent>